<img src="multiqc/templates/default/assets/img/MultiQC_logo.png" width="300" title="MultiQC">

### Aggregate bioinformatics results across many samples into a single report.

##### Find [documentation](http://multiqc.info/docs) and [example reports](http://multiqc.info/examples/rna-seq/multiqc_report.html) at [http://multiqc.info](http://multiqc.info)

[![PyPI Version](https://img.shields.io/pypi/v/multiqc.svg?style=flat-square)](https://pypi.python.org/pypi/multiqc/)
[![Conda Version](https://anaconda.org/bioconda/multiqc/badges/version.svg)](https://anaconda.org/bioconda/multiqc)
[![Build Status](https://img.shields.io/travis/ewels/MultiQC.svg?style=flat-square)](https://travis-ci.org/ewels/MultiQC)
[![Gitter](https://img.shields.io/badge/gitter-%20join%20chat%20%E2%86%92-4fb99a.svg?style=flat-square)](https://gitter.im/ewels/MultiQC)


-----

MultiQC is a tool to create a single report with interactive plots
for multiple bioinformatics analyses across many samples.

MultiQC is written in Python (tested with v2.7 / v3.4 / v3.5). It is
available on the [Python Package Index](https://pypi.python.org/pypi/multiqc/)
and through conda using [Bioconda](http://bioconda.github.io/).

Reports are generated by scanning given directories for recognised log files.
These are parsed and a single HTML report is generated summarising the statistics
for all logs found. MultiQC reports can describe multiple analysis steps and
large numbers of samples within a single plot, and multiple analysis tools making
it ideal for routine fast quality control.

Currently, supported tools include:

* Quality control & pre-processing
  * [Cutadapt](https://code.google.com/p/cutadapt/)
  * [FastQC](http://www.bioinformatics.babraham.ac.uk/projects/fastqc/)
  * [FastQ Screen](http://www.bioinformatics.babraham.ac.uk/projects/fastq_screen/)
  * [Skewer](https://github.com/relipmoc/skewer)
  * [Trimmomatic](http://www.usadellab.org/cms/?page=trimmomatic)
* Read aligners / quantifiers
  * [Bismark](http://www.bioinformatics.babraham.ac.uk/projects/bismark/)
  * [Bowtie](http://bowtie-bio.sourceforge.net)
  * [Bowtie 2](http://bowtie-bio.sourceforge.net/bowtie2/)
  * [HiCUP](http://www.bioinformatics.babraham.ac.uk/projects/hicup/)
  * [Kallisto](http://pachterlab.github.io/kallisto/)
  * [Salmon](http://combine-lab.github.io/salmon/)
  * [STAR](https://github.com/alexdobin/STAR)
  * [Tophat](https://ccb.jhu.edu/software/tophat/)
* Post-alignment tools
  * [Bamtools](https://github.com/pezmaster31/bamtools) (`stats`)
  * [Bcftools](https://samtools.github.io/bcftools/) (`stats`)
  * [GATK](https://software.broadinstitute.org/gatk/) (`VariantEval`)
  * [methylQA](http://methylqa.sourceforge.net/)
  * [Picard](http://broadinstitute.github.io/picard/) (`MarkDuplicates`, `InsertSizeMetrics`, `GcBiasMetrics`, `HsMetrics`, `OxoGMetrics`, `BaseDistributionByCycle`, `RnaSeqMetrics`, `AlignmentSummaryMetrics`)
  * [Preseq](http://smithlabresearch.org/software/preseq/)
  * [Qualimap](http://qualimap.bioinfo.cipf.es/) (`BamQC`, `RNASeq`)
  * [QUAST](http://quast.bioinf.spbau.ru/)
  * [RSeQC](http://rseqc.sourceforge.net/) (`bam_stat`, `gene_body_coverage`,  `infer_experiment`,`inner_distance`, `junction_annotation`, `junction_saturation`, `read_distribution`, `read_duplication`, `read_gc`)
  * [Samblaster](https://github.com/GregoryFaust/samblaster)
  * [Samtools](http://www.htslib.org) (`stats`, `flagstats`, `idxstats`)
  * [SnpEff](http://snpeff.sourceforge.net/)
  * [Subread featureCounts](http://bioinf.wehi.edu.au/featureCounts/)

More modules are being written all of the time. Please suggest any ideas as a new
[issue](https://github.com/ewels/MultiQC/issues) _(include an example log
file if possible)_.

## Installation

You can install MultiQC from [PyPI](https://pypi.python.org/pypi/multiqc/)
using `pip` as follows:

```
pip install multiqc
```

If you would like the development version instead, the command is:

```
pip install git+https://github.com/ewels/MultiQC.git
```

Alternatively, you can install using [Conda](http://anaconda.org/)
from the [bioconda channel](https://bioconda.github.io/):
```
conda install -c bioconda multiqc
```

MultiQC is also available in the
[Galaxy Toolshed](https://toolshed.g2.bx.psu.edu/view/engineson/multiqc/).

## Usage
Once installed, you can use MultiQC by navigating to your analysis directory
(or a parent directory) and running the tool:

```
multiqc .
```

That's it! MultiQC will scan the specified directory ('.' is the current dir)
and produce a report detailing whatever it finds.

The report is created in `multiqc_report.html` by default. Tab-delimited data
files are also created in `multiqc_data/`, containing extra information.
These can be easily inspected using Excel (use `--data-format` to get `yaml`
or `json` instead).

For more detailed instructions, run `multiqc -h` or see the
[documentation](http://multiqc.info/docs/#running-multiqc).

## Contributions & Support

Contributions and suggestions for new features are welcome, as are bug reports!
Please create a new [issue](https://github.com/ewels/MultiQC/issues) for any
of these, including example reports where possible. MultiQC has extensive
[documentation](http://multiqc.info/docs) describing how to write new modules,
plugins and templates.

There is a chat room for the package hosted on Gitter where you can discuss
things with the package author and other developers:
https://gitter.im/ewels/MultiQC

If in doubt, feel free to get in touch with the author directly:
[@ewels](https://github.com/ewels) (phil.ewels@scilifelab.se)

### Contributors
Project lead and main author: [@ewels](https://github.com/ewels)

Code contributions from:
[@moonso](https://github.com/moonso),
[@lpantano](https://github.com/lpantano),
[@dakl](https://github.com/dakl),
[@robinandeer](https://github.com/robinandeer),
[@mlusignan](https://github.com/mlusignan),
[@HLWiencko](https://github.com/HLWiencko),
[@guillermo-carrasco](https://github.com/guillermo-carrasco),
[@avilella](https://github.com/avilella)
and many others. Thanks for your support!

